FolderType
==========

.. currentmodule:: wwt_data_formats.enums

.. autoclass:: FolderType
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~FolderType.EARTH
      ~FolderType.PANORAMA
      ~FolderType.PLANET
      ~FolderType.SKY
      ~FolderType.UNSPECIFIED

   .. rubric:: Attributes Documentation

   .. autoattribute:: EARTH
   .. autoattribute:: PANORAMA
   .. autoattribute:: PLANET
   .. autoattribute:: SKY
   .. autoattribute:: UNSPECIFIED
